@@ -78,7 +78,7 @@ ProcessExecutor::ProcessExecutor(const std::list<FileWithDetails> &files, const
 namespace {
     class PipeWriter : public ErrorLogger {
     public:
-        enum PipeSignal : std::uint8_t {REPORT_OUT='1',REPORT_ERROR='2', CHILD_END='5'};
+        enum PipeSignal : std::uint8_t {REPORT_OUT='1',REPORT_ERROR='2',REPORT_SUPPR_INLINE='3',REPORT_SUPPR='4',CHILD_END='5',REPORT_METRIC='6'};
 
         explicit PipeWriter(int pipe) : mWpipe(pipe) {}
 
@@ -90,11 +90,37 @@ namespace {
             writeToPipe(REPORT_ERROR, msg.serialize());
         }
 
+        void writeSuppr(const SuppressionList &supprs) const {
+            for (const auto& suppr : supprs.getSuppressions())
+            {
+                if (suppr.isInline)
+                    writeToPipe(REPORT_SUPPR_INLINE, suppressionToString(suppr));
+                else if (suppr.checked)
+                    writeToPipe(REPORT_SUPPR, suppressionToString(suppr));
+            }
+        }
+
+        void reportMetric(const std::string &metric) override {
+            writeToPipe(REPORT_METRIC, metric);
+        }
+
         void writeEnd(const std::string& str) const {
             writeToPipe(CHILD_END, str);
         }
 
     private:
+        static std::string suppressionToString(const SuppressionList::Suppression &suppr)
+        {
+            std::string suppr_str = suppr.toString();
+            suppr_str += ";";
+            suppr_str += suppr.checked ? "1" : "0";
+            suppr_str += ";";
+            suppr_str += suppr.matched ? "1" : "0";
+            suppr_str += ";";
+            suppr_str += suppr.extraComment;
+            return suppr_str;
+        }
+
         // TODO: how to log file name in error?
         void writeToPipeInternal(PipeSignal type, const void* data, std::size_t to_write) const
         {
@@ -124,7 +150,7 @@ namespace {
                 writeToPipeInternal(type, &len, l_size);
             }
 
-            if (len > 0)
+            if (len > 0) // TODO: unexpected - write a warning?
                 writeToPipeInternal(type, data.c_str(), len);
         }
 
@@ -155,7 +181,12 @@ bool ProcessExecutor::handleRead(int rpipe, unsigned int &result, const std::str
         std::exit(EXIT_FAILURE);
     }
 
-    if (type != PipeWriter::REPORT_OUT && type != PipeWriter::REPORT_ERROR && type != PipeWriter::CHILD_END) {
+    if (type != PipeWriter::REPORT_OUT &&
+        type != PipeWriter::REPORT_ERROR &&
+        type != PipeWriter::REPORT_SUPPR_INLINE &&
+        type != PipeWriter::REPORT_SUPPR &&
+        type != PipeWriter::CHILD_END &&
+        type != PipeWriter::REPORT_METRIC) {
         std::cerr << "#### ThreadExecutor::handleRead(" << filename << ") invalid type " << int(type) << std::endl;
         std::exit(EXIT_FAILURE);
     }
@@ -174,7 +205,7 @@ bool ProcessExecutor::handleRead(int rpipe, unsigned int &result, const std::str
     }
 
     std::string buf(len, '\0');
-    if (len > 0) {
+    if (len > 0) { // TODO: unexpected - write a warning?
         char *data_start = &buf[0];
         bytes_to_read = len;
         do {
@@ -206,9 +237,38 @@ bool ProcessExecutor::handleRead(int rpipe, unsigned int &result, const std::str
 
         if (hasToLog(msg))
             mErrorLogger.reportErr(msg);
+    } else if (type == PipeWriter::REPORT_SUPPR_INLINE || type == PipeWriter::REPORT_SUPPR) {
+        if (!buf.empty()) {
+            // TODO: avoid string splitting
+            auto parts = splitString(buf, ';');
+            if (parts.size() < 4)
+            {
+                // TODO: make this non-fatal
+                std::cerr << "#### ThreadExecutor::handleRead(" << filename << ") adding of inline suppression failed - insufficient data" << std::endl;
+                std::exit(EXIT_FAILURE);
+            }
+            auto suppr = SuppressionList::parseLine(parts[0]);
+            suppr.isInline = (type == PipeWriter::REPORT_SUPPR_INLINE);
+            suppr.checked = parts[1] == "1";
+            suppr.matched = parts[2] == "1";
+            suppr.extraComment = parts[3];
+            for (std::size_t i = 4; i < parts.size(); i++) {
+                suppr.extraComment += ";" + parts[i];
+            }
+            const std::string err = mSuppressions.nomsg.addSuppression(suppr);
+            if (!err.empty()) {
+                // TODO: only update state if it doesn't exist - otherwise propagate error
+                mSuppressions.nomsg.updateSuppressionState(suppr); // TODO: check result
+                // TODO: make this non-fatal
+                //std::cerr << "#### ThreadExecutor::handleRead(" << filename << ") adding of inline suppression failed - " << err << std::endl;
+                //std::exit(EXIT_FAILURE);
+            }
+        }
     } else if (type == PipeWriter::CHILD_END) {
         result += std::stoi(buf);
         res = false;
+    } else if (type == PipeWriter::REPORT_METRIC) {
+        mErrorLogger.reportMetric(buf);
     }
 
     return res;
@@ -289,14 +349,13 @@ unsigned int ProcessExecutor::check()
 
                 if (iFileSettings != mFileSettings.end()) {
                     resultOfCheck = fileChecker.check(*iFileSettings);
-                    if (mSettings.clangTidy)
-                        fileChecker.analyseClangTidy(*iFileSettings);
                 } else {
                     // Read file from a file
                     resultOfCheck = fileChecker.check(*iFile);
-                    // TODO: call analyseClangTidy()?
                 }
 
+                pipewriter.writeSuppr(mSuppressions.nomsg);
+
                 pipewriter.writeEnd(std::to_string(resultOfCheck));
                 std::exit(EXIT_SUCCESS);
             }
