@@ -27,7 +27,7 @@
 #include <cctype>
 #include <fstream>
 #include <iostream>
-#include <sstream>
+#include <map>
 #include <utility>
 
 #include "json.h"
@@ -282,7 +282,7 @@ std::string Settings::applyEnabled(const std::string &str, bool enable)
     }
     // FIXME: hack to make sure "error" is always enabled
     severity.enable(Severity::error);
-    return errmsg;
+    return {};
 }
 
 bool Settings::isEnabled(const ValueFlow::Value *value, bool inconclusiveCheck) const
@@ -392,15 +392,21 @@ static const std::set<std::string> autosarCheckers{
 
 static const std::set<std::string> certCCheckers{
     "IOWithoutPositioning",
+    "argumentSize",
+    "arrayIndexOutOfBounds",
+    "arrayIndexOutOfBoundsCond",
+    "arrayIndexThenCheck",
     "autoVariables",
     "autovarInvalidDeallocation",
     "bitwiseOnBoolean",
+    "bufferAccessOutOfBounds",
     "comparePointers",
     "danglingLifetime",
     "deallocret",
     "deallocuse",
     "doubleFree",
     "floatConversionOverflow",
+    "integerOverflow",
     "invalidFunctionArg",
     "invalidLengthModifierError",
     "invalidLifetime",
@@ -412,11 +418,15 @@ static const std::set<std::string> certCCheckers{
     "memleakOnRealloc",
     "mismatchAllocDealloc",
     "missingReturn",
+    "negativeIndex",
     "nullPointer",
     "nullPointerArithmetic",
     "nullPointerArithmeticRedundantCheck",
     "nullPointerDefaultArg",
     "nullPointerRedundantCheck",
+    "objectIndex",
+    "pointerOutOfBounds",
+    "pointerOutOfBoundsCond",
     "preprocessorErrorDirective",
     "resourceLeak",
     "returnDanglingLifetime",
@@ -455,6 +465,8 @@ static const std::set<std::string> certCppCheckers{
     "operatorEqToSelf",
     "returnDanglingLifetime",
     "sizeofCalculation",
+    "uninitStructMember",
+    "uninitdata",
     "uninitvar",
     "virtualCallInConstructor",
     "virtualDestructor"
@@ -546,6 +558,49 @@ static const std::set<std::string> misrac2023Checkers{
     "writeReadOnlyFile"
 };
 
+static const std::set<std::string> misrac2025Checkers{
+    "argumentSize",
+    "autovarInvalidDeallocation",
+    "bufferAccessOutOfBounds",
+    "comparePointers",
+    "compareValueOutOfTypeRangeError",
+    "constParameterPointer",
+    "constStatement",
+    "danglingLifetime",
+    "danglingTemporaryLifetime",
+    "duplicateBreak",
+    "funcArgNamesDifferent",
+    "incompatibleFileOpen",
+    "invalidFunctionArg",
+    "knownConditionTrueFalse",
+    "leakNoVarFunctionCall",
+    "leakReturnValNotUsed",
+    "memleak",
+    "memleakOnRealloc",
+    "missingReturn",
+    "overlappingWriteFunction",
+    "overlappingWriteUnion",
+    "pointerOutOfBounds",
+    "preprocessorErrorDirective",
+    "redundantAssignInSwitch",
+    "redundantAssignment",
+    "redundantCondition",
+    "resourceLeak",
+    "returnDanglingLifetime",
+    "shadowVariable",
+    "sizeofCalculation",
+    "sizeofwithsilentarraypointer",
+    "syntaxError",
+    "uninitvar",
+    "unknownEvaluationOrder",
+    "unreachableCode",
+    "unreadVariable",
+    "unusedLabel",
+    "unusedVariable",
+    "useClosedFile",
+    "writeReadOnlyFile"
+};
+
 static const std::set<std::string> misracpp2008Checkers{
     "autoVariables",
     "comparePointers",
@@ -602,6 +657,7 @@ static const std::set<std::string> misracpp2023Checkers{
     "constParameterReference",
     "ctuOneDefinitionRuleViolation",
     "danglingLifetime",
+    "floatConversionOverflow",
     "identicalConditionAfterEarlyExit",
     "identicalInnerCondition",
     "ignoredReturnValue",
@@ -639,7 +695,7 @@ bool Settings::isPremiumEnabled(const char id[]) const
         return true;
     if (premiumArgs.find("cert-c++") != std::string::npos && certCppCheckers.count(id))
         return true;
-    if (premiumArgs.find("misra-c-") != std::string::npos && (misrac2012Checkers.count(id) || misrac2023Checkers.count(id)))
+    if (premiumArgs.find("misra-c-") != std::string::npos && (misrac2012Checkers.count(id) || misrac2023Checkers.count(id) || misrac2025Checkers.count(id)))
         return true;
     if (premiumArgs.find("misra-c++-2008") != std::string::npos && misracpp2008Checkers.count(id))
         return true;
@@ -648,51 +704,6 @@ bool Settings::isPremiumEnabled(const char id[]) const
     return false;
 }
 
-void Settings::setMisraRuleTexts(const ExecuteCmdFn& executeCommand)
-{
-    if (premiumArgs.find("--misra-c-20") != std::string::npos) {
-        const auto it = std::find_if(addonInfos.cbegin(), addonInfos.cend(), [](const AddonInfo& a) {
-            return a.name == "premiumaddon.json";
-        });
-        if (it != addonInfos.cend()) {
-            std::string arg;
-            if (premiumArgs.find("--misra-c-2023") != std::string::npos)
-                arg = "--misra-c-2023-rule-texts";
-            else
-                arg = "--misra-c-2012-rule-texts";
-            std::string output;
-            executeCommand(it->executable, {std::move(arg)}, "2>&1", output);
-            setMisraRuleTexts(output);
-        }
-    }
-}
-
-void Settings::setMisraRuleTexts(const std::string& data)
-{
-    mMisraRuleTexts.clear();
-    std::istringstream istr(data);
-    std::string line;
-    while (std::getline(istr, line)) {
-        std::string::size_type pos = line.find(' ');
-        if (pos == std::string::npos)
-            continue;
-        std::string id = line.substr(0, pos);
-        std::string text = line.substr(pos + 1);
-        if (id.empty() || text.empty())
-            continue;
-        if (text[text.size() -1] == '\r')
-            text.erase(text.size() -1);
-        mMisraRuleTexts[id] = std::move(text);
-    }
-}
-
-std::string Settings::getMisraRuleText(const std::string& id, const std::string& text) const {
-    if (id.compare(0, 9, "misra-c20") != 0)
-        return text;
-    const auto it = mMisraRuleTexts.find(id.substr(id.rfind('-') + 1));
-    return it != mMisraRuleTexts.end() ? it->second : text;
-}
-
 Settings::ExecutorType Settings::defaultExecutor()
 {
     static constexpr ExecutorType defaultExecutor =
