@@ -32,9 +32,7 @@
 #include <algorithm>
 #include <atomic>
 #include <cstdint>
-#include <functional>
 #include <list>
-#include <map>
 #include <set>
 #include <string>
 #include <tuple>
@@ -69,16 +67,16 @@ public:
         mFlags = 0xFFFFFFFF;
     }
     bool isEnabled(T flag) const {
-        return (mFlags & (1U << (uint32_t)flag)) != 0;
+        return (mFlags & (1U << static_cast<uint32_t>(flag))) != 0;
     }
     void enable(T flag) {
-        mFlags |= (1U << (uint32_t)flag);
+        mFlags |= (1U << static_cast<uint32_t>(flag));
     }
     void enable(SimpleEnableGroup<T> group) {
         mFlags |= group.intValue();
     }
     void disable(T flag) {
-        mFlags &= ~(1U << (uint32_t)flag);
+        mFlags &= ~(1U << static_cast<uint32_t>(flag));
     }
     void disable(SimpleEnableGroup<T> group) {
         mFlags &= ~(group.intValue());
@@ -97,6 +95,7 @@ public:
  * to pass individual values to functions or constructors now or in the
  * future when we might have even more detailed settings.
  */
+// NOLINTNEXTLINE(clang-analyzer-optin.performance.Padding)
 class CPPCHECKLIB WARN_UNUSED Settings {
 private:
 
@@ -122,6 +121,9 @@ public:
     /** @brief Path to the python interpreter to be used to run addons. */
     std::string addonPython;
 
+    /** @brief Analyze all configuration in Visual Studio project. */
+    bool analyzeAllVsConfigs{true};
+
     /** @brief Paths used as base for conversion to relative paths. */
     std::vector<std::string> basePaths;
 
@@ -137,7 +139,7 @@ public:
     /**
      * Check code in the headers, this is on by default but can
      * be turned off to save CPU */
-    bool checkHeaders = true; // TODO: CLI
+    bool checkHeaders = true;
 
     /** Check for incomplete info in library files? */
     bool checkLibrary{};
@@ -152,7 +154,7 @@ public:
     std::set<std::string> checkUnknownFunctionReturn; // TODO: move to Library?
 
     /** Check unused/uninstantiated templates */
-    bool checkUnusedTemplates = true; // TODO: CLI
+    bool checkUnusedTemplates = true;
 
     /** Use Clang */
     bool clang{};
@@ -161,7 +163,10 @@ public:
     std::string clangExecutable = "clang";
 
     /** Use clang-tidy */
-    bool clangTidy{}; // TODO: CLI
+    bool clangTidy{};
+
+    /** Custom clang-tidy executable */
+    std::string clangTidyExecutable = "clang-tidy";
 
     /** Internal: Clear the simplecpp non-existing include cache */
     bool clearIncludeCache{}; // internal
@@ -181,9 +186,15 @@ public:
     /** @brief Are we running from DACA script? */
     bool daca{};
 
+    /** @brief Is --debug-ast given? */
+    bool debugast{};
+
     /** @brief Is --debug-clang-output given? */
     bool debugClangOutput{};
 
+    /** @brief Is --debug-ignore given? */
+    bool debugignore{};
+
     /** @brief Internal: Is --debug-lookup or --debug-lookup=all given? */
     bool debuglookup{};
 
@@ -205,9 +216,15 @@ public:
     /** @brief Is --debug-simplified given? */
     bool debugSimplified{};
 
+    /** @brief Is --debug-symdb given? */
+    bool debugsymdb{};
+
     /** @brief Is --debug-template given? */
     bool debugtemplate{};
 
+    /** @brief Is --debug-valueflow given? */
+    bool debugvalueflow{};
+
     /** @brief Is --debug-warnings given? */
     bool debugwarnings{};
 
@@ -217,9 +234,6 @@ public:
     /** @brief Do not filter duplicated errors. */
     bool emitDuplicates{};
 
-    /** @brief Name of the language that is enforced. Empty per default. */
-    Standards::Language enforcedLang{};
-
 #if defined(USE_WINDOWS_SEH) || defined(USE_UNIX_SIGNAL_HANDLING)
     /** @brief Is --exception-handling given */
     bool exceptionHandling{};
@@ -524,17 +538,12 @@ public:
 
     void setCheckLevel(CheckLevel level);
 
-    using ExecuteCmdFn = std::function<int (std::string,std::vector<std::string>,std::string,std::string&)>;
-    void setMisraRuleTexts(const ExecuteCmdFn& executeCommand);
-    void setMisraRuleTexts(const std::string& data);
-    std::string getMisraRuleText(const std::string& id, const std::string& text) const;
 
     static ExecutorType defaultExecutor();
 
 private:
     static std::string parseEnabled(const std::string &str, std::tuple<SimpleEnableGroup<Severity>, SimpleEnableGroup<Checks>> &groups);
     std::string applyEnabled(const std::string &str, bool enable);
-    std::map<std::string, std::string> mMisraRuleTexts;
 };
 
 /// @}
