@@ -9,18 +9,23 @@
 
 // cppcheck-suppress-file valueFlowBailout
 
-#include <boost/config.hpp>
+#include <cstdio>
+#include <new>
+#include <tuple>
+
+#include <boost/config.hpp> // IWYU pragma: keep
 #include <boost/math/special_functions/round.hpp>
-#include <boost/endian/conversion.hpp>
+#include <boost/endian/conversion.hpp> // IWYU pragma: keep
 #include <boost/bind/bind.hpp>
-#include <boost/function.hpp>
+#include <boost/function.hpp> // IWYU pragma: keep
 #include <boost/smart_ptr/scoped_array.hpp>
-#include <boost/thread/mutex.hpp>
+#include <boost/thread/mutex.hpp> // IWYU pragma: keep
 #include <boost/thread/lock_guard.hpp>
-#include <boost/test/unit_test.hpp>
+#include <boost/test/unit_test.hpp> // IWYU pragma: keep
 #include <boost/core/scoped_enum.hpp>
 #include <boost/foreach.hpp>
 
+#include <cstdlib>
 #include <set>
 #include <vector>
 
@@ -162,6 +167,18 @@ void test_BOOST_FOREACH_6(std::vector<int> data)
     }
 }
 
+void test_require()
+{
+    int *some_int = static_cast<int*>(std::malloc(sizeof(int)));
+    int *some_other_int = static_cast<int*>(malloc(sizeof(int)));
+    BOOST_REQUIRE(some_int);
+    BOOST_TEST_REQUIRE(some_other_int);
+    *some_int = 42;
+    *some_other_int = 42;
+    std::free(some_int);
+    free(some_other_int);
+}
+
 BOOST_AUTO_TEST_SUITE(my_auto_test_suite)
 
 BOOST_AUTO_TEST_CASE(test_message_macros)
